@@ -5,6 +5,8 @@ package Lingua::Word::Parser;
 use strict;
 use warnings;
 
+our $VERSION = '0.06';
+
 use Bit::Vector;
 use DBI;
 use List::PowerSet qw( powerset_lazy );
@@ -19,8 +21,6 @@ memoize('score_parts');
 memoize('_rle');
 memoize('_or_together');
 
-our $VERSION = '0.05';
-
 
 
 sub new {
@@ -106,7 +106,7 @@ sub _db_fetch {
 sub knowns {
     my $self = shift;
 
-    # TODO What is this?
+    # The identifier for the known and masks lists.
     my $id = 0;
 
     for my $i (values %{ $self->{lex} }) {
@@ -289,7 +289,7 @@ sub _rle {
     $scored =~ s/1/k/g; # Undigitize
     $scored =~ s/0/u/g; # "
     # Count contiguous chars.
-    $scored =~ s/(.)\1*/$1. length $&/ge;
+    $scored =~ s/(.)\1*/$1 . length(substr($scored, $-[0], $+[0]-$-[0]))/ge;
     return $scored;
 }
 
@@ -381,7 +381,7 @@ Lingua::Word::Parser - Parse a word into known and unknown parts
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -399,7 +399,7 @@ version 0.05
     dbpass => 's3kr1+',
  );
 
- my ($known) = $p->knowns;
+ my ($known, $masks) = $p->knowns;
  my $combos  = $p->power;
  my $parts   = $p->score_parts;
  my $scored  = $p->score;
@@ -419,7 +419,7 @@ the form:
  (?<=\w)o(?=\w) combining
  (?<=\w)tic     possessing
 
-A database lexicon must have (affix, definition) records of the form:
+A database lexicon must have records of the form:
 
          affix     definition
   -----------------------------
@@ -439,7 +439,6 @@ Create a new C<Lingua::Word::Parser> object.
 Arguments and defaults:
 
   word:   undef
-  lex:    undef
   dbuser: undef
   dbpass: undef
   dbname: undef
@@ -448,15 +447,16 @@ Arguments and defaults:
 
 =head2 knowns()
 
-Fingerprint the known word parts.
+Find the known word parts and their bitstring masks.
 
 =head2 power()
 
-Find the "non-overlapping powerset."
+Find the powerset of non-overlapping known word parts.
 
 =head2 score()
 
-  $score = $p->score( $open_sparator, $close_separator, $line_terminator );
+  $score = $p->score();
+  $score = $p->score( $open_sparator, $close_separator);
 
 Score the known vs unknown word part combinations into ratios of characters and
 chunks or parts or "spans of adjacent characters" B<as a collection of strings>.
@@ -466,14 +466,19 @@ default.
 
 =head2 score_parts()
 
-  $score = $p->score_parts( $open_sparator, $close_separator );
+  $score_parts = $p->score_parts();
+  $score_parts = $p->score_parts( $open_sparator, $close_separator );
+  $score_parts = $p->score_parts( $open_sparator, $close_separator, $line_terminator );
 
 Score the known vs unknown word part combinations into ratios of characters and
-chunks or parts or "spans of adjacent characters."
+chunks (spans of adjacent characters).
 
 If not given, the B<$open_sparator> and B<$close_separator> are '<' and '>' by
 default.
 
+The line terminator can be any string, like a newline (C<\n> or an HTML
+line-break), but is the empty string (C<''>) by default.
+
 =head1 SEE ALSO
 
 L<Lingua::TokenParse> - The predecessor of this module.
